Subject: Fix spelling errors
Author: Olivier Salllou <olivier.sallou@irisa.fr>
Description: fix spelling errors in man pages
Last-Updated: 09/11/11
--- a/lib/Bio/GMOD/DB/Adapter.pm
+++ b/lib/Bio/GMOD/DB/Adapter.pm
@@ -868,7 +868,7 @@
 
 =item Returns
 
-On create, void.  With an arguement, returns the requested file handle
+On create, void.  With an argument, returns the requested file handle
 
 =item Arguments
 
@@ -968,7 +968,7 @@
 
 =item Returns
 
-See Arguements.
+See Arguments.
 
 =item Arguments
 
@@ -3476,7 +3476,7 @@
 --   short identifier that can help people find an analysis they
 --   want. for instance "tRNAscan", "cDNA", "FlyPep", "SwissProt"
 --   it should not be assumed to be unique. for instance, there may
---   be lots of seperate analyses done against a cDNA database.
+--   be lots of separate analyses done against a cDNA database.
 --
 -- program: not NULL   (and programversion is NOT NULL...)
 --   e.g. blastx, blastp, sim4, genscan
--- a/lib/Bio/GMOD/Config2.pm
+++ b/lib/Bio/GMOD/Config2.pm
@@ -81,7 +81,7 @@
 
 Takes one optional argument that is the path to the root of the GMOD 
 installation.  If that argument is not provided, Bio::GMOD::Config will
-fall back to the enviroment variable GMOD_ROOT, which should be defined
+fall back to the environment variable GMOD_ROOT, which should be defined
 for any GMOD installation.
 
 =cut
@@ -267,7 +267,7 @@
 
 =head2 appendHash($tohash, $addhash, $replace)
 
-add keys to hash without  replacing existing .. prefered behavior ?
+add keys to hash without  replacing existing .. preferred behavior ?
 unless $replace is flagged
 
 =cut
--- a/lib/Bio/GMOD/Config.pm
+++ b/lib/Bio/GMOD/Config.pm
@@ -41,7 +41,7 @@
 
 Takes one optional argument that is the path to the root of the GMOD 
 installation.  If that argument is not provided, Bio::GMOD::Config will
-fall back to the enviroment variable GMOD_ROOT, which should be defined
+fall back to the environment variable GMOD_ROOT, which should be defined
 for any GMOD installation.
 
 =cut
--- a/lib/Bio/GMOD/Bulkfiles/SWISS_CRC64.pm
+++ b/lib/Bio/GMOD/Bulkfiles/SWISS_CRC64.pm
@@ -7,7 +7,7 @@
 
 =head2 SYNOPSIS
 
-** dgg: rewrite for line-add so dont need to suck all into mem **
+** dgg: rewrite for line-add so don't need to suck all into mem **
 
    use SWISS::CRC64;
    
--- a/bin/gmod_gff3_preprocessor.pl
+++ b/bin/gmod_gff3_preprocessor.pl
@@ -24,7 +24,7 @@
  --gfffile        The file containing GFF3 (optional, can read
                      from stdin)
  --outfile        The name kernel that will be used for naming result files
- --splitfile      Split the files into more managable chunks, providing
+ --splitfile      Split the files into more manageable chunks, providing
                      an argument to control splitting
  --onlysplit      Split the files and then quit (ie, don't sort)
  --nosplit        Don't split the files (ie, only sort)
@@ -61,7 +61,7 @@
 =head2 FASTA sequence
 
 If the GFF3 file contains FASTA sequence at the end, the sequence
-will be placed in a separate file with the extention '.fasta'.  This
+will be placed in a separate file with the extension '.fasta'.  This
 fasta file can be loaded separately after the split and/or sorted
 GFF3 files are loaded, using the command:
 
--- a/bin/gmod_make_gff_from_dbxref.pl
+++ b/bin/gmod_make_gff_from_dbxref.pl
@@ -21,7 +21,7 @@
 
 =head1 DESCRIPTION
 
-This tool takes a list of tab seperated db identifiers and accessions on
+This tool takes a list of tab separated db identifiers and accessions on
 the command line (like gmod_extract_dbxref_from_gff.pl would produce)
 along with a directory containing fasta files and creates a GFF file.
 The script tries several options for identifying the accession in the
--- a/bin/gmod_materialized_view_tool.pl
+++ b/bin/gmod_materialized_view_tool.pl
@@ -59,7 +59,7 @@
 =item 1 Data syncronisity
 
 When normal tables are updated with values that are reflected in a MV,
-there will be a delay (usually a very noticable one) between when 
+there will be a delay (usually a very noticeable one) between when
 the normal table is updated and when the MV is updated.  This tool
 provides the means of updating the MVs; see --automatic below.
 
--- a/load/bin/bulk_load_gff3.PLS
+++ b/load/bin/bulk_load_gff3.PLS
@@ -90,7 +90,7 @@
                      to use the current directory)
  --no_target_syn   By default, the loader adds the targetId in 
                      the synonyms list of the feature. This flag 
-                     desactivate this.
+                     deactivate this.
  --unique_target   Trust the unicity of the target IDs. IDs are case 
                      sensitive. By default, the uniquename of a new target 
                      will be 'TargetId_PrimaryKey'. With this flag, 
@@ -256,7 +256,7 @@
 db_name must have an entry in the db table, with a value of 
 db.name equal to 'DB:db_name'; several database names were preinstalled
 with the database when 'make prepdb' was run.  Execute 'SELECT name
-FROM db' to find out what databases are already availble.  New dbxref
+FROM db' to find out what databases are already available.  New dbxref
 entries are created in the dbxref table, and dbxrefs are linked to
 features via the feature_dbxref table.
 

--- a/lib/Bio/GMOD/Bulkfiles/GenbankSubmitWriter.pm
+++ b/lib/Bio/GMOD/Bulkfiles/GenbankSubmitWriter.pm
@@ -640,7 +640,7 @@
   full of match: analysis types (messy names, types, etc.)
   -- no feats written to fff in many hours !? - due to holding BAC and cytoband features
   -- try dropping gffForwards; maybe better (gff written) but still memuse balloons
   -- added clearFinishedObs() - no apparent help; dont see what else is holding objects here
    -- ok now, added min base loc to keep in oidobs, delete all before
        runs fast - chr 3L in 10 min. instead of >2hr.
   
@@ -775,8 +775,8 @@
     
     if (!$type && $DEBUG && !/NULL|repeatmask/) { print STDERR "missing type: $_\n";  } ##<< repeatmasker kid objs
     if ($type eq 'skip' || !$type) { # or what? undef? got some bad feats w/ no type??
        ## dont keep old oid: ($l_arm,$l_oid,$l_fmin)= ($arm,$oid,$fmin);
        ##dont save arm for skip !? if changed here, cant miss below openout..
       ($l_oid,$l_fmin)= (-1,$fmin);
 	    next;
 	    }
@@ -827,7 +827,7 @@
       else {
       ## FIXME - bad if fob not in @fobs 
       ## .. e.g. repeat region - many locs over arm, few oid's
       ## most of these we dont want to join - too far apart; need max_max setting below to keep small ranges together?
         # print STDERR "missed join to last $type,$name,$oid\n" if $DEBUG;
         }
       }
@@ -875,7 +875,7 @@
       if ($flushok) {
         if ($self->hasObForwards(\@fobs, \%oidobs)) {
           $flushok = 0;
-          $min_max= $fmin + 2000; ##smaller step so we dont miss chance to flush
+          $min_max= $fmin + 2000; ##smaller step so we don't miss chance to flush
           }
         warn "hasObForwards no=$flushok at $fmin $type:$name $oid\n" if ($DEBUG>1);
         }
@@ -908,7 +908,7 @@
       $fob= $newob;
       foreach my $fk (keys %addfob) { $fob->{$fk}= $addfob{$fk}; } %addfob=();
       
         #?? dont add here if it is simple feature; wait till know if it is parent or kid?
         # this is bad for 'gene' NOT? simple feat
       unless( $simplefeat{$type} ) { 
         $oidobs{$oid}->{fob}= $newob; 
@@ -1157,7 +1157,7 @@
           }
         }
       }
-    ## else {  } # $iskid only - dont save
+    ## else {  } # $iskid only - don't save
     }
     
   return \@cobs;
@@ -1256,7 +1256,7 @@
  looks like chado pg reporting instance with CDS_exons is bad for transspliced mod(mdg4)
 
  08may: change behavior for GenbankSubmit to offsetLocation: 
-    dont return Genbank style string location, but
+    don't return Genbank style string location, but
     adjust @loc to CDS_exons by CDS span offset;
  See also getCDSexons and makeCompound
  
@@ -1573,7 +1573,7 @@
       ## for each gene model part; should add locus_tag == gene ID
       
 #       if ($gff_keepoids) { $at{$k} .= ATTR_LISTCHAR if $at{$k}; $at{$k} .= $v; }
-      next if $segmentfeats{$type}; # dont do parent for these ... ?
+      next if $segmentfeats{$type}; # don't do parent for these ... ?
       
       $v =~ s/:.*$//;  
       $k= 'Parent'; 
@@ -640,7 +640,7 @@
   -- no feats written to fff in many hours !? - due to holding BAC and cytoband features
   -- try dropping gffForwards; maybe better (gff written) but still memuse balloons
-  -- added clearFinishedObs() - no apparent help; dont see what else is holding objects here
+  -- added clearFinishedObs() - no apparent help; don't see what else is holding objects here
    -- ok now, added min base loc to keep in oidobs, delete all before
        runs fast - chr 3L in 10 min. instead of >2hr.
@@ -775,8 +775,8 @@
     if (!$type && $DEBUG && !/NULL|repeatmask/) { print STDERR "missing type: $_\n";  } ##<< repeatmasker kid objs
     if ($type eq 'skip' || !$type) { # or what? undef? got some bad feats w/ no type??
-       ## dont keep old oid: ($l_arm,$l_oid,$l_fmin)= ($arm,$oid,$fmin);
-       ##dont save arm for skip !? if changed here, cant miss below openout..
+       ## don't keep old oid: ($l_arm,$l_oid,$l_fmin)= ($arm,$oid,$fmin);
+       ##don't save arm for skip !? if changed here, cant miss below openout..
       ($l_oid,$l_fmin)= (-1,$fmin);
 	    next;
@@ -827,7 +827,7 @@
       ## FIXME - bad if fob not in @fobs 
       ## .. e.g. repeat region - many locs over arm, few oid's
-      ## most of these we dont want to join - too far apart; need max_max setting below to keep small ranges together?
+      ## most of these we don't want to join - too far apart; need max_max setting below to keep small ranges together?
         # print STDERR "missed join to last $type,$name,$oid\n" if $DEBUG;
         }
@@ -908,7 +908,7 @@
       foreach my $fk (keys %addfob) { $fob->{$fk}= $addfob{$fk}; } %addfob=();
       
-        #?? dont add here if it is simple feature; wait till know if it is parent or kid?
+        #?? don't add here if it is simple feature; wait till know if it is parent or kid?
         # this is bad for 'gene' NOT? simple feat
       unless( $simplefeat{$type} ) { 